==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/annotated.js <==
var annotated =
[
    [ "Steinberg", null, [
      [ "FUnknownImpl", null, null ],
      [ "Vst", null, [
        [ "Algo", "namespaceSteinberg_1_1Vst_1_1Algo.html", null ],
        [ "Helpers", "namespaceSteinberg_1_1Vst_1_1Helpers.html", null ],
        [ "InterAppAudio", "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html", "namespaceSteinberg_1_1Vst_1_1InterAppAudio" ],
        [ "MPE", "namespaceSteinberg_1_1Vst_1_1MPE.html", "namespaceSteinberg_1_1Vst_1_1MPE" ],
        [ "SampleAccurate", "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html", "namespaceSteinberg_1_1Vst_1_1SampleAccurate" ],
        [ "Test", "namespaceSteinberg_1_1Vst_1_1Test.html", null ],
        [ "AudioBuffer", "classSteinberg_1_1Vst_1_1AudioBuffer.html", "classSteinberg_1_1Vst_1_1AudioBuffer" ],
        [ "BypassProcessor", "classSteinberg_1_1Vst_1_1BypassProcessor.html", "classSteinberg_1_1Vst_1_1BypassProcessor" ],
        [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", "classSteinberg_1_1Vst_1_1FileStream" ],
        [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", "classSteinberg_1_1Vst_1_1ReadOnlyBStream" ],
        [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", "classSteinberg_1_1Vst_1_1BufferStream" ],
        [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ],
        [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ],
        [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
        [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ],
        [ "TestingPluginContext", "structSteinberg_1_1Vst_1_1TestingPluginContext.html", null ],
        [ "TestDefaults", "structSteinberg_1_1Vst_1_1TestDefaults.html", "structSteinberg_1_1Vst_1_1TestDefaults" ],
        [ "TestBase", "classSteinberg_1_1Vst_1_1TestBase.html", "classSteinberg_1_1Vst_1_1TestBase" ],
        [ "TestEnh", "classSteinberg_1_1Vst_1_1TestEnh.html", "classSteinberg_1_1Vst_1_1TestEnh" ],
        [ "ParamPoint", "classSteinberg_1_1Vst_1_1ParamPoint.html", "classSteinberg_1_1Vst_1_1ParamPoint" ],
        [ "ParamChanges", "classSteinberg_1_1Vst_1_1ParamChanges.html", "classSteinberg_1_1Vst_1_1ParamChanges" ],
        [ "StringResult", "exceptionSteinberg_1_1Vst_1_1StringResult.html", "exceptionSteinberg_1_1Vst_1_1StringResult" ],
        [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1ProcessContextRequirements" ],
        [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", "classSteinberg_1_1Vst_1_1ProcessDataSlicer" ],
        [ "RTTransferT", "structSteinberg_1_1Vst_1_1RTTransferT.html", "structSteinberg_1_1Vst_1_1RTTransferT" ]
      ] ],
      [ "OneReaderOneWriter", "namespaceSteinberg_1_1OneReaderOneWriter.html", "namespaceSteinberg_1_1OneReaderOneWriter" ],
      [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
      [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
      [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ]
    ] ],
    [ "VST3", "namespaceVST3.html", "namespaceVST3" ],
    [ "VSTGUI", "namespaceVSTGUI.html", null ],
    [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", "interfaceVSTInterAppAudioAppDelegateBase" ]
];

==> vst3sdk-docs-3.7.9_build_61-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/annotated.js <==
var annotated =
[
    [ "Steinberg", null, [
      [ "FUnknownImpl", null, null ],
      [ "Vst", null, [
        [ "Algo", "namespaceSteinberg_1_1Vst_1_1Algo.html", null ],
        [ "Helpers", "namespaceSteinberg_1_1Vst_1_1Helpers.html", null ],
        [ "InterAppAudio", "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html", "namespaceSteinberg_1_1Vst_1_1InterAppAudio" ],
        [ "MPE", "namespaceSteinberg_1_1Vst_1_1MPE.html", "namespaceSteinberg_1_1Vst_1_1MPE" ],
        [ "SampleAccurate", "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html", "namespaceSteinberg_1_1Vst_1_1SampleAccurate" ],
        [ "Test", "namespaceSteinberg_1_1Vst_1_1Test.html", null ],
        [ "AudioBuffer", "classSteinberg_1_1Vst_1_1AudioBuffer.html", "classSteinberg_1_1Vst_1_1AudioBuffer" ],
        [ "BypassProcessor", "classSteinberg_1_1Vst_1_1BypassProcessor.html", "classSteinberg_1_1Vst_1_1BypassProcessor" ],
        [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", "classSteinberg_1_1Vst_1_1FileStream" ],
        [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", "classSteinberg_1_1Vst_1_1ReadOnlyBStream" ],
        [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", "classSteinberg_1_1Vst_1_1BufferStream" ],
        [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ],
        [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ],
        [ "IDataExchangeHandlerHost", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost" ],
        [ "HostDataExchangeHandler", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler" ],
        [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
        [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ],
        [ "TestingPluginContext", "structSteinberg_1_1Vst_1_1TestingPluginContext.html", null ],
        [ "TestDefaults", "structSteinberg_1_1Vst_1_1TestDefaults.html", "structSteinberg_1_1Vst_1_1TestDefaults" ],
        [ "TestBase", "classSteinberg_1_1Vst_1_1TestBase.html", "classSteinberg_1_1Vst_1_1TestBase" ],
        [ "TestEnh", "classSteinberg_1_1Vst_1_1TestEnh.html", "classSteinberg_1_1Vst_1_1TestEnh" ],
        [ "ParamPoint", "classSteinberg_1_1Vst_1_1ParamPoint.html", "classSteinberg_1_1Vst_1_1ParamPoint" ],
        [ "ParamChanges", "classSteinberg_1_1Vst_1_1ParamChanges.html", "classSteinberg_1_1Vst_1_1ParamChanges" ],
        [ "StringResult", "exceptionSteinberg_1_1Vst_1_1StringResult.html", "exceptionSteinberg_1_1Vst_1_1StringResult" ],
        [ "DataExchangeHandler", "classSteinberg_1_1Vst_1_1DataExchangeHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeHandler" ],
        [ "DataExchangeReceiverHandler", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler" ],
        [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1ProcessContextRequirements" ],
        [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", "classSteinberg_1_1Vst_1_1ProcessDataSlicer" ],
        [ "RTTransferT", "structSteinberg_1_1Vst_1_1RTTransferT.html", "structSteinberg_1_1Vst_1_1RTTransferT" ],
        [ "SystemTime", "classSteinberg_1_1Vst_1_1SystemTime.html", "classSteinberg_1_1Vst_1_1SystemTime" ]
      ] ],
      [ "OneReaderOneWriter", "namespaceSteinberg_1_1OneReaderOneWriter.html", "namespaceSteinberg_1_1OneReaderOneWriter" ],
      [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
      [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
      [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ]
    ] ],
    [ "VST3", "namespaceVST3.html", "namespaceVST3" ],
    [ "VSTGUI", "namespaceVSTGUI.html", null ],
    [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", "interfaceVSTInterAppAudioAppDelegateBase" ]
];
